NodeStatus

Struct NodeStatus 

pub struct NodeStatus {
Show 15 fields pub catchpoint: Option<String>, pub catchpoint_acquired_blocks: Option<u64>, pub catchpoint_processed_accounts: Option<u64>, pub catchpoint_total_accounts: Option<u64>, pub catchpoint_total_blocks: Option<u64>, pub catchpoint_verified_accounts: Option<u64>, pub catchup_time: u64, pub last_catchpoint: Option<String>, pub last_round: u64, pub last_version: String, pub next_version: String, pub next_version_round: u64, pub next_version_supported: bool, pub stopped_at_unsupported_round: bool, pub time_since_last_round: u64,
}
Information about the status of a node

Fields

catchpoint: Option<String>

The current catchpoint that is being caught up to

catchpoint_acquired_blocks: Option<u64>

The number of blocks that have already been obtained by the node as part of the catchup

catchpoint_processed_accounts: Option<u64>

The number of accounts from the current catchpoint that have been processed so far as part of the catchup

catchpoint_total_accounts: Option<u64>

The total number of accounts included in the current catchpoint

catchpoint_total_blocks: Option<u64>

The total number of blocks that are required to complete the current catchpoint catchup

catchpoint_verified_accounts: Option<u64>

The number of accounts from the current catchpoint that have been verified so far as part of the catchup

catchup_time: u64

CatchupTime in nanoseconds

last_catchpoint: Option<String>

The last catchpoint seen by the node

last_round: u64

LastRound indicates the last round seen.

last_version: String

LastVersion indicates the last consensus version supported.

next_version: String

NextVersion of consensus protocol to use.

next_version_round: u64

NextVersionRound is the round at which the next consensus version will apply

next_version_supported: bool

NextVersionSupported indicates whether the next consensus version is supported by this node

stopped_at_unsupported_round: bool

StoppedAtUnsupportedRound indicates that the node does not support the new rounds and has stopped making progress.

time_since_last_round: u64

TimeSinceLastRound in nanoseconds.